@@ -1,37 +1,49 @@
+#include <assert.h>
+#include <errno.h>
+#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
 #include <unistd.h>
-#include <assert.h>
-#include <errno.h>
 
 #include <poll.h>
 
-#include <sys/stat.h>
 #include <fcntl.h>
+#include <sys/stat.h>
 
 #include <libudev.h>
+#include <tllist.h>
 
 #define LOG_MODULE "battery"
-#define LOG_ENABLE_DBG 1
-#include "../log.h"
+#define LOG_ENABLE_DBG 0
 #include "../bar/bar.h"
-#include "../config.h"
 #include "../config-verify.h"
+#include "../config.h"
+#include "../log.h"
 #include "../plugin.h"
 
 #define max(x, y) ((x) > (y) ? (x) : (y))
 
 static const long min_poll_interval = 250;
 static const long default_poll_interval = 60 * 1000;
+static const long one_sec_in_ns = 1000000000;
 
 enum state { STATE_FULL, STATE_NOTCHARGING, STATE_CHARGING, STATE_DISCHARGING, STATE_UNKNOWN };
 
-struct private {
+struct current_state {
+    long ema;
+    long current;
+    struct timespec time;
+};
+
+struct private
+{
     struct particle *label;
 
     long poll_interval;
+    int battery_scale;
+    long smoothing_scale;
     char *battery;
     char *manufacturer;
     char *model;
@@ -45,16 +57,53 @@ struct private {
     long energy;
     long power;
     long charge;
-    long current;
+    struct current_state ema_current;
     long time_to_empty;
     long time_to_full;
 };
 
+static int64_t
+difftimespec_ns(const struct timespec after, const struct timespec before)
+{
+    return ((int64_t)after.tv_sec - (int64_t)before.tv_sec) * (int64_t)one_sec_in_ns
+           + ((int64_t)after.tv_nsec - (int64_t)before.tv_nsec);
+}
+
+// Linear Exponential Moving Average (unevenly spaced time series)
+// http://www.eckner.com/papers/Algorithms%20for%20Unevenly%20Spaced%20Time%20Series.pdf
+// Adapted from: https://github.com/andreas50/utsAlgorithms/blob/master/ema.c
 static void
-timespec_sub(const struct timespec *a, const struct timespec *b,
-             struct timespec *res)
+ema_linear(struct current_state *state, struct current_state curr, long tau)
+{
+    double w, w2, tmp;
+
+    if (state->current == -1) {
+        *state = curr;
+        return;
+    }
+
+    long time = difftimespec_ns(curr.time, state->time);
+    tmp = time / (double)tau;
+    w = exp(-tmp);
+    if (tmp > 1e-6) {
+        w2 = (1 - w) / tmp;
+    } else {
+        // Use taylor expansion for numerical stability
+        w2 = 1 - tmp / 2 + tmp * tmp / 6 - tmp * tmp * tmp / 24;
+    }
+
+    double ema = state->ema * w + curr.current * (1 - w2) + state->current * (w2 - w);
+
+    state->ema = ema;
+    state->current = curr.current;
+    state->time = curr.time;
+
+    LOG_DBG("ema current: %ld", (long)ema);
+}
+
+static void
+timespec_sub(const struct timespec *a, const struct timespec *b, struct timespec *res)
 {
-    const long one_sec_in_ns = 1000000000;
 
     res->tv_sec = a->tv_sec - b->tv_sec;
     res->tv_nsec = a->tv_nsec - b->tv_nsec;
@@ -96,11 +145,8 @@ content(struct module *mod)
 
     mtx_lock(&mod->lock);
 
-    assert(m->state == STATE_FULL ||
-           m->state == STATE_NOTCHARGING ||
-           m->state == STATE_CHARGING ||
-           m->state == STATE_DISCHARGING ||
-           m->state == STATE_UNKNOWN);
+    assert(m->state == STATE_FULL || m->state == STATE_NOTCHARGING || m->state == STATE_CHARGING
+           || m->state == STATE_DISCHARGING || m->state == STATE_UNKNOWN);
 
     unsigned long hours;
     unsigned long minutes;
@@ -113,9 +159,8 @@ content(struct module *mod)
         minutes = m->time_to_full / 60;
         hours = minutes / 60;
         minutes = minutes % 60;
-    } else if  (m->energy_full >= 0 && m->charge && m->power >= 0) {
-        unsigned long energy = m->state == STATE_CHARGING
-            ? m->energy_full - m->energy : m->energy;
+    } else if (m->energy_full >= 0 && m->charge && m->power >= 0) {
+        unsigned long energy = m->state == STATE_CHARGING ? m->energy_full - m->energy : m->energy;
 
         double hours_as_float;
         if (m->state == STATE_FULL || m->state == STATE_NOTCHARGING)
@@ -127,15 +172,14 @@ content(struct module *mod)
 
         hours = hours_as_float;
         minutes = (hours_as_float - (double)hours) * 60;
-    } else if (m->charge_full >= 0 && m->charge >= 0 && m->current >= 0) {
-        unsigned long charge = m->state == STATE_CHARGING
-            ? m->charge_full - m->charge : m->charge;
+    } else if (m->charge_full >= 0 && m->charge >= 0 && m->ema_current.current >= 0) {
+        unsigned long charge = m->state == STATE_CHARGING ? m->charge_full - m->charge : m->charge;
 
         double hours_as_float;
         if (m->state == STATE_FULL || m->state == STATE_NOTCHARGING)
             hours_as_float = 0.0;
-        else if (m->current > 0)
-            hours_as_float = (double)charge / m->current;
+        else if (m->ema_current.current > 0)
+            hours_as_float = (double)charge / m->ema_current.current;
         else
             hours_as_float = 99.0;
 
@@ -232,8 +276,7 @@ initialize(struct private *m)
     {
         int fd = openat(base_dir_fd, "manufacturer", O_RDONLY);
         if (fd == -1) {
-            LOG_WARN("/sys/class/power_supply/%s/manufacturer: %s",
-                     m->battery, strerror(errno));
+            LOG_WARN("/sys/class/power_supply/%s/manufacturer: %s", m->battery, strerror(errno));
             m->manufacturer = NULL;
         } else {
             m->manufacturer = strdup(readline_from_fd(fd, sizeof(line_buf), line_buf));
@@ -244,8 +287,7 @@ initialize(struct private *m)
     {
         int fd = openat(base_dir_fd, "model_name", O_RDONLY);
         if (fd == -1) {
-            LOG_WARN("/sys/class/power_supply/%s/model_name: %s",
-                     m->battery, strerror(errno));
+            LOG_WARN("/sys/class/power_supply/%s/model_name: %s", m->battery, strerror(errno));
             m->model = NULL;
         } else {
             m->model = strdup(readline_from_fd(fd, sizeof(line_buf), line_buf));
@@ -253,9 +295,8 @@ initialize(struct private *m)
         }
     }
 
-    if (faccessat(base_dir_fd, "energy_full_design", O_RDONLY, 0) == 0 &&
-        faccessat(base_dir_fd, "energy_full", O_RDONLY, 0) == 0)
-    {
+    if (faccessat(base_dir_fd, "energy_full_design", O_RDONLY, 0) == 0
+        && faccessat(base_dir_fd, "energy_full", O_RDONLY, 0) == 0) {
         {
             int fd = openat(base_dir_fd, "energy_full_design", O_RDONLY);
             if (fd == -1) {
@@ -281,9 +322,8 @@ initialize(struct private *m)
         m->energy_full = m->energy_full_design = -1;
     }
 
-    if (faccessat(base_dir_fd, "charge_full_design", O_RDONLY, 0) == 0 &&
-        faccessat(base_dir_fd, "charge_full", O_RDONLY, 0) == 0)
-    {
+    if (faccessat(base_dir_fd, "charge_full_design", O_RDONLY, 0) == 0
+        && faccessat(base_dir_fd, "charge_full", O_RDONLY, 0) == 0) {
         {
             int fd = openat(base_dir_fd, "charge_full_design", O_RDONLY);
             if (fd == -1) {
@@ -291,7 +331,7 @@ initialize(struct private *m)
                 goto err;
             }
 
-            m->charge_full_design = readint_from_fd(fd);
+            m->charge_full_design = readint_from_fd(fd) / m->battery_scale;
             close(fd);
         }
 
@@ -302,7 +342,7 @@ initialize(struct private *m)
                 goto err;
             }
 
-            m->charge_full = readint_from_fd(fd);
+            m->charge_full = readint_from_fd(fd) / m->battery_scale;
             close(fd);
         }
     } else {
@@ -366,6 +406,10 @@ update_status(struct module *mod)
     long time_to_empty = time_to_empty_fd >= 0 ? readint_from_fd(time_to_empty_fd) : -1;
     long time_to_full = time_to_full_fd >= 0 ? readint_from_fd(time_to_full_fd) : -1;
 
+    if (charge >= -1) {
+        charge /= m->battery_scale;
+    }
+
     char buf[512];
     const char *status = readline_from_fd(status_fd, sizeof(buf), buf);
 
@@ -409,16 +453,23 @@ update_status(struct module *mod)
     }
 
     LOG_DBG("capacity: %ld, energy: %ld, power: %ld, charge=%ld, current=%ld, "
-            "time-to-empty: %ld, time-to-full: %ld", capacity, energy, power,
-            charge, current, time_to_empty, time_to_full);
+            "time-to-empty: %ld, time-to-full: %ld",
+            capacity, energy, power, charge, current, time_to_empty, time_to_full);
 
     mtx_lock(&mod->lock);
+    if (m->state != state) {
+        m->ema_current = (struct current_state){-1, 0, (struct timespec){0, 0}};
+    }
     m->state = state;
     m->capacity = capacity;
     m->energy = energy;
     m->power = power;
     m->charge = charge;
-    m->current = current;
+    if (current != -1) {
+        struct timespec t;
+        clock_gettime(CLOCK_MONOTONIC, &t);
+        ema_linear(&m->ema_current, (struct current_state){current, current, t}, m->smoothing_scale);
+    }
     m->time_to_empty = time_to_empty;
     m->time_to_full = time_to_full;
     mtx_unlock(&mod->lock);
@@ -434,13 +485,10 @@ run(struct module *mod)
     if (!initialize(m))
         return -1;
 
-    LOG_INFO("%s: %s %s (at %.1f%% of original capacity)",
-             m->battery, m->manufacturer, m->model,
-             (m->energy_full > 0
-              ? 100.0 * m->energy_full / m->energy_full_design
-              : m->charge_full > 0
-              ? 100.0 * m->charge_full / m->charge_full_design
-              : 0.0));
+    LOG_INFO("%s: %s %s (at %.1f%% of original capacity)", m->battery, m->manufacturer, m->model,
+             (m->energy_full > 0   ? 100.0 * m->energy_full / m->energy_full_design
+              : m->charge_full > 0 ? 100.0 * m->charge_full / m->charge_full_design
+                                   : 0.0));
 
     int ret = 1;
 
@@ -495,12 +543,11 @@ run(struct module *mod)
             struct udev_device *dev = udev_monitor_receive_device(mon);
             if (dev != NULL) {
                 const char *sysname = udev_device_get_sysname(dev);
-                udev_for_us =
-                    sysname != NULL && strcmp(sysname, m->battery) == 0;
+                udev_for_us = sysname != NULL && strcmp(sysname, m->battery) == 0;
 
                 if (!udev_for_us) {
-                    LOG_DBG("udev notification not for us (%s != %s)",
-                            m->battery, sysname != sysname ? sysname : "NULL");
+                    LOG_DBG("udev notification not for us (%s != %s)", m->battery,
+                            sysname != sysname ? sysname : "NULL");
                 } else
                     LOG_DBG("triggering update due to udev notification");
 
@@ -526,11 +573,9 @@ run(struct module *mod)
             struct timespec timeout_consumed;
             timespec_sub(&time_after_poll, &time_before_poll, &timeout_consumed);
 
-            const int timeout_consumed_ms =
-                timeout_consumed.tv_sec * 1000 + timeout_consumed.tv_nsec / 1000000;
+            const int timeout_consumed_ms = timeout_consumed.tv_sec * 1000 + timeout_consumed.tv_nsec / 1000000;
 
-            LOG_DBG("timeout-left before: %dms, consumed: %dms, updated: %dms",
-                    timeout_left_ms, timeout_consumed_ms,
+            LOG_DBG("timeout-left before: %dms, consumed: %dms, updated: %dms", timeout_left_ms, timeout_consumed_ms,
                     max(timeout_left_ms - timeout_consumed_ms, 0));
 
             timeout_left_ms -= timeout_consumed_ms;
@@ -548,13 +593,17 @@ out:
 }
 
 static struct module *
-battery_new(const char *battery, struct particle *label, long poll_interval_msecs)
+battery_new(const char *battery, struct particle *label, long poll_interval_msecs, int battery_scale,
+            long smoothing_secs)
 {
     struct private *m = calloc(1, sizeof(*m));
     m->label = label;
     m->poll_interval = poll_interval_msecs;
+    m->battery_scale = battery_scale;
+    m->smoothing_scale = smoothing_secs * one_sec_in_ns;
     m->battery = strdup(battery);
     m->state = STATE_UNKNOWN;
+    m->ema_current = (struct current_state){-1, 0, (struct timespec){0, 0}};
 
     struct module *mod = module_common_new();
     mod->private = m;
@@ -571,13 +620,13 @@ from_conf(const struct yml_node *node, struct conf_inherit inherited)
     const struct yml_node *c = yml_get_value(node, "content");
     const struct yml_node *name = yml_get_value(node, "name");
     const struct yml_node *poll_interval = yml_get_value(node, "poll-interval");
+    const struct yml_node *battery_scale = yml_get_value(node, "battery-scale");
+    const struct yml_node *smoothing_secs = yml_get_value(node, "smoothing-secs");
 
-    return battery_new(
-        yml_value_as_string(name),
-        conf_to_particle(c, inherited),
-        (poll_interval != NULL
-         ? yml_value_as_int(poll_interval)
-         : default_poll_interval));
+    return battery_new(yml_value_as_string(name), conf_to_particle(c, inherited),
+                       (poll_interval != NULL ? yml_value_as_int(poll_interval) : default_poll_interval),
+                       (battery_scale != NULL ? yml_value_as_int(battery_scale) : 1),
+                       (smoothing_secs != NULL ? yml_value_as_int(smoothing_secs) : 100));
 }
 
 static bool
@@ -589,8 +638,7 @@ conf_verify_poll_interval(keychain_t *chain, const struct yml_node *node)
     const long value = yml_value_as_int(node);
 
     if (value != 0 && value < min_poll_interval) {
-        LOG_ERR("%s: interval value cannot be less than %ldms",
-                conf_err_prefix(chain, node), min_poll_interval);
+        LOG_ERR("%s: interval value cannot be less than %ldms", conf_err_prefix(chain, node), min_poll_interval);
         return false;
     }
 
@@ -603,6 +651,8 @@ verify_conf(keychain_t *chain, const struct yml_node *node)
     static const struct attr_info attrs[] = {
         {"name", true, &conf_verify_string},
         {"poll-interval", false, &conf_verify_poll_interval},
+        {"battery-scale", false, &conf_verify_unsigned},
+        {"smoothing-secs", false, &conf_verify_unsigned},
         MODULE_COMMON_ATTRS,
     };
 
