@@ -1,7 +1,7 @@
 #pragma once
 
-#include <stddef.h>
 #include <stdbool.h>
+#include <stddef.h>
 
 enum tag_type {
     TAG_TYPE_BOOL,
@@ -43,21 +43,16 @@ struct tag_set {
 };
 
 struct tag *tag_new_int(struct module *owner, const char *name, long value);
-struct tag *tag_new_int_range(
-    struct module *owner, const char *name, long value, long min, long max);
-struct tag *tag_new_int_realtime(
-    struct module *owner, const char *name, long value, long min,
-    long max, enum tag_realtime_unit unit);
+struct tag *tag_new_int_range(struct module *owner, const char *name, long value, long min, long max);
+struct tag *tag_new_int_realtime(struct module *owner, const char *name, long value, long min, long max,
+                                 enum tag_realtime_unit unit);
 struct tag *tag_new_bool(struct module *owner, const char *name, bool value);
 struct tag *tag_new_float(struct module *owner, const char *name, double value);
-struct tag *tag_new_string(
-    struct module *owner, const char *name, const char *value);
+struct tag *tag_new_string(struct module *owner, const char *name, const char *value);
 
 const struct tag *tag_for_name(const struct tag_set *set, const char *name);
 void tag_set_destroy(struct tag_set *set);
 
 /* Utility functions */
 char *tags_expand_template(const char *template, const struct tag_set *tags);
-void tags_expand_templates(
-    char *expanded[], const char *template[], size_t nmemb,
-    const struct tag_set *tags);
+void tags_expand_templates(char *expanded[], const char *template[], size_t nmemb, const struct tag_set *tags);
